Settings
========

Quade includes a Settings class that encapsulates various configuration options.

Available Settings
------------------

.. module:: quade

.. autoclass:: Settings
   :members: access_test_func, allowed_envs, fixtures_file, use_celery
   :undoc-members:

Convenience Classes and Methods
-------------------------------

.. automodule:: quade.settings
   :members:
